==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/fa/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'دارایی ها محول شده به :',
    'bulk_update_warn'	=> 'شما در حال خواندن مشخصات خواص کاربر user_count هستید. لطفا توجه داشته باشید که نمیتوانید ویژگیهای کاربر خود را با استفاده از این فرم تغییر دهید و باید به صورت جداگانه به کاربر خود ویرایش کنید.',
    'bulk_update_help'	=> 'این فرم به شما امکان می دهد چندین بار در یک بار به روز کنید. فقط فیلمی را که باید تغییر دهید را پر کنید. هر فیلدی که خالی باقی می ماند بدون تغییر باقی خواهد ماند.',
    'current_assets'    => 'دارایی های اکنون  برای این کاربر بیرون کشیده شد',
    'clone'             => 'کلون کاربر',
    'contact_user'      => 'تماس با:',
    'edit'              => 'ویرایش کاربر',
    'filetype_info'     => 'پسوند های مجاز:png, gif, jpg, jpeg, doc, docx, pdf, txt, zip,Rar',
    'history_user'      => 'تاریخچه برای:',
	'info'				=> 'اطلاعات',
    'restore_user'		=> 'برای بازسازی آنها اینجا کلیک کنید.',
    'last_login'        => 'آخرین ورود',
    'ldap_config_text'  => 'تنظشیمات تاییدیه LDPA در فولدر app/config در فایلی به نام idap.php وجود دارد.مکان مشخص شده برای تمامی کاربران وارد شده تنظیم میشود.شما نیاز دارید که حداقل یه مکان را اضافه کرده باشید تا بتوانید از این ویژگی استفاده کنید.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'برنامه چک شد برای:',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'نمایش کاربر :',
    'usercsv'           => 'فایل CSV',
    'two_factor_admin_optin_help' => 'تنظیمات مدیریت فعلی شما اجازه اجرای مجدد احراز هویت دو عامل را می دهد.',
    'two_factor_enrolled' => 'دستگاه 2FA ثبت شده است',
    'two_factor_active'   => '2FA فعال',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/fa/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'دارایی ها محول شده به :',
    'bulk_update_warn'	=> 'شما در حال خواندن مشخصات خواص کاربر user_count هستید. لطفا توجه داشته باشید که نمیتوانید ویژگیهای کاربر خود را با استفاده از این فرم تغییر دهید و باید به صورت جداگانه به کاربر خود ویرایش کنید.',
    'bulk_update_help'	=> 'این فرم به شما امکان می دهد چندین بار در یک بار به روز کنید. فقط فیلمی را که باید تغییر دهید را پر کنید. هر فیلدی که خالی باقی می ماند بدون تغییر باقی خواهد ماند.',
    'current_assets'    => 'دارایی های اکنون  برای این کاربر بیرون کشیده شد',
    'clone'             => 'کلون کاربر',
    'contact_user'      => 'تماس با:',
    'edit'              => 'ویرایش کاربر',
    'filetype_info'     => 'پسوند های مجاز:png, gif, jpg, jpeg, doc, docx, pdf, txt, zip,Rar',
    'history_user'      => 'تاریخچه برای:',
    'info'				=> 'اطلاعات',
    'restore_user'		=> 'برای بازسازی آنها اینجا کلیک کنید.',
    'last_login'        => 'آخرین ورود',
    'ldap_config_text'  => 'تنظشیمات تاییدیه LDPA در فولدر app/config در فایلی به نام idap.php وجود دارد.مکان مشخص شده برای تمامی کاربران وارد شده تنظیم میشود.شما نیاز دارید که حداقل یه مکان را اضافه کرده باشید تا بتوانید از این ویژگی استفاده کنید.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'برنامه چک شد برای:',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'نمایش کاربر :',
    'usercsv'           => 'فایل CSV',
    'two_factor_admin_optin_help' => 'تنظیمات مدیریت فعلی شما اجازه اجرای مجدد احراز هویت دو عامل را می دهد.',
    'two_factor_enrolled' => 'دستگاه 2FA ثبت شده است',
    'two_factor_active'   => '2FA فعال',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
